@@ -1,7 +1,7 @@
 
 #==============================================================================#
 # exerb/archiveheader.rb
-# $Id: archiveheader.rb,v 1.4 2002/09/20 09:12:12 yuya Exp $
+# $Id: archiveheader.rb,v 1.7 2003/01/14 10:29:07 yuya Exp $
 #==============================================================================#
 
 #==============================================================================#
@@ -17,6 +17,10 @@ module Exerb
     OPTIONS_KCODE_SJIS = 2
     OPTIONS_KCODE_UTF8 = 3
 
+    ENTRY_TYPE_SCRIPT  = 1
+    ENTRY_TYPE_LIBRARY = 2
+    ENTRY_TYPE_BINARY  = 3
+
     #==========================================================================#
     # Initialize Method
 
@@ -25,10 +29,8 @@ module Exerb
       @time_date_stamp  = nil
       @offset_to_name   = nil
       @number_of_name   = nil
-      @offset_to_script = nil
-      @number_of_script = nil
-      @offset_to_dll    = nil
-      @number_of_dll    = nil
+      @offset_to_entry  = nil
+      @number_of_entry  = nil
       @options          = nil
     end
 
@@ -36,20 +38,20 @@ module Exerb
     # Accessor
 
     attr_accessor :signature, :time_date_stamp, :offset_to_name, :number_of_name,
-                  :offset_to_script, :number_of_script, :offset_to_dll, :number_of_dll, :options
+                  :offset_to_entry, :number_of_entry, :options
 
     #==========================================================================#
     # Class Methods
 
     def self.size
-      return 4 * 9
+      return 4 * 7
     end
 
     #==========================================================================#
     # Instance Methods
 
     def pack
-      return [@signature, @time_date_stamp, @offset_to_name, @number_of_name, @offset_to_script, @number_of_script, @offset_to_dll, @number_of_dll, @options].pack('Z4L8')
+      return [@signature, @time_date_stamp, @offset_to_name, @number_of_name, @offset_to_entry, @number_of_entry, @options].pack('Z4L6')
     end
 
   end # ArchiveHeader
