@@ -1,7 +1,7 @@
 
 #==============================================================================#
 # exerb/binary.rb
-# $Id: binary.rb,v 1.6 2002/09/20 09:12:12 yuya Exp $
+# $Id: binary.rb,v 1.8 2002/10/13 03:43:04 yuya Exp $
 #==============================================================================#
 
 #==============================================================================#
@@ -19,8 +19,20 @@ module Exerb
       #========================================================================#
       # Initialize Method
 
-      def initialize(binary)
-        @binary = binary
+      def initialize(binary, compress = false)
+        unless binary[0, 4] == 'RUBY'
+          raise 'the header of the archive has invalid signature'
+        end
+
+        if compress
+          require 'zlib'
+          @binary = Zlib::Deflate.deflate(binary, Deflate::DEFAULT_COMPRESSION)
+        else
+          @binary = binary
+        end
+
+        @original_size   = binary.size
+        @compressed_size = (compress ? @binary.size : 0)
       end
 
       #========================================================================#
@@ -34,13 +46,14 @@ module Exerb
       # Instance Methods
 
       def size
-        return @binary.size
+        return @original_size
+      end
+
+      def compressed_size
+        return @compressed_size
       end
 
       def selfcheck
-        unless @binary[0, 4] == 'RUBY'
-          raise 'the header of the archive has invalid signature'
-        end
       end
 
       def output(io)
@@ -56,8 +69,9 @@ module Exerb
       #========================================================================#
       # Class Constants
 
-      ARCHIVE_OFFSET = 0x34
-      ARCHIVE_SIZE   = 0x38
+      ARCHIVE_OFFSET = 0x30
+      ARCHIVE_SIZE   = 0x34
+      ARCHIVE_CSIZE  = 0x38
 
       #========================================================================#
       # Initialize Method
@@ -96,6 +110,14 @@ module Exerb
         @binary[ARCHIVE_SIZE, 4] = [value].pack('I')
       end
 
+      def archive_compressed_size
+        return @binary[ARCHIVE_CSIZE, 4].unpack('I')[0]
+      end
+
+      def archive_compressed_size=(value)
+        @binary[ARCHIVE_CSIZE, 4] = [value].pack('I')
+      end
+
       def selfcheck
         unless @binary[0, 2] == 'MZ'
           raise 'the header of the core has invalid signature'
@@ -133,8 +155,9 @@ module Exerb
       end
 
       def output(io)
-        @core.archive_offset = @core.size
-        @core.archive_size   = @archive.size
+        @core.archive_offset          = @core.size
+        @core.archive_size            = @archive.size
+        @core.archive_compressed_size = @archive.compressed_size
         @core.output(io)
         @archive.output(io)
       end
