@@ -1,17 +1,16 @@
 
 #==============================================================================#
 # exerb/exerb.rb
-# $Id: exerb.rb,v 1.5 2002/11/13 12:07:54 yuya Exp $
+# $Id: exerb.rb,v 1.7 2003/01/21 05:34:54 yuya Exp $
 #==============================================================================#
 
+require 'exerb/recipefile.rb'
 require 'exerb/archive'
 require 'exerb/archiveheader'
 require 'exerb/nameheader'
-require 'exerb/scriptheader'
-require 'exerb/dllheader'
 require 'exerb/nametable'
-require 'exerb/scripttable'
-require 'exerb/dlltable'
+require 'exerb/entryheader'
+require 'exerb/entrytable'
 require 'exerb/binary'
 require 'exerb/version'
 
