@@ -3,20 +3,17 @@
 // Used by resource.rc
 //
 #define IDS_FAIL_CREATEFILE             1
-#define IDS_FAIL_MAPVIEWOFFILE          2
-#define IDS_SCRIPT_NOT_FOUND            3
-#define IDS_FAIL_MODIFY_IMPORT_TABLE    4
-#define IDS_FAIL_GETPROCADDRESS         5
-#define IDS_CANNOT_EXECUTE_SCRIPT       6
-#define IDS_CANNOT_OBTAIN_EXCEPTION     7
-#define IDS_HEADER_NOT_FOUND            8
+#define IDS_SCRIPT_NOT_FOUND            2
+#define IDS_FAIL_MODIFY_IMPORT_TABLE    3
+#define IDS_FAIL_GETPROCADDRESS         4
+#define IDS_CANNOT_EXECUTE_SCRIPT       5
+#define IDS_HEADER_NOT_FOUND            6
 #define IDD_EXCEPTION                   101
 #define IDI_RUBY                        102
 #define IDI_EXCEPTION                   103
 #define ID_CLOSE                        1000
-#define ID_DETAIL                       1001
-#define IDC_EDIT_MESSAGE                1002
-#define IDC_EDIT_CALLSTACK              1003
+#define IDC_EDIT_MESSAGE                1001
+#define IDC_EDIT_CALLSTACK              1002
 #define IDC_EDIT_BACKTRACE              1003
 #define IDC_EDIT_TYPE                   1004
 
