@@ -1,4 +1,4 @@
-// $Id: exerb.h,v 1.10 2003/01/10 04:42:50 yuya Exp $
+// $Id: exerb.h,v 1.15 2003/01/30 07:43:50 yuya Exp $
 
 ////////////////////////////////////////////////////////////////////////////////
 
@@ -12,9 +12,15 @@
 #include <map>
 #include <string>
 #include <sys/stat.h>
+
 #include "ruby.h"
+
+#ifdef NT
 #include "win32/win32.h"
+#endif
+
 #include "pe.h"
+#include "exerbmod.h"
 #include "def.h"
 #include "resource.h"
 
@@ -22,6 +28,10 @@
 #include "zlib.h"
 #endif
 
+#ifdef USE_BRUBY
+#include "BRb.h"
+#endif
+
 ////////////////////////////////////////////////////////////////////////////////
 
 #ifdef _DEBUG
@@ -46,6 +56,7 @@ typedef void (*ON_FAIL_FNC)(VALUE);
 ////////////////////////////////////////////////////////////////////////////////
 
 int  ExMain(int argc, char **argv, ON_ERROR_FNC onerror, ON_FAIL_FNC onfail);
-void ExGetSelfFileName(LPSTR pszBuffer, UINT uiBufferSize);
+void ExGetSelfFilePath(LPSTR filepath_buffer, UINT size);
+void ExGetSelfFileName(LPSTR filename_buffer, UINT size);
 
 ////////////////////////////////////////////////////////////////////////////////
